summaryrefslogtreecommitdiffstats
path: root/kword/KWDeleteDia.h
diff options
context:
space:
mode:
Diffstat (limited to 'kword/KWDeleteDia.h')
-rw-r--r--kword/KWDeleteDia.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kword/KWDeleteDia.h b/kword/KWDeleteDia.h
index 9a2ad6d5..e2ce9ff4 100644
--- a/kword/KWDeleteDia.h
+++ b/kword/KWDeleteDia.h
@@ -33,19 +33,20 @@ class KWView;
class KWDeleteDia : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
enum DeleteType {deleteRow, deleteColumn};
/**
* Constructor for the ok-to-delete dialog.
* @param parent the parent widget
* @param name the internal name for the widget
* @param table the table the rows or columns are to be deleted from
* @param type the type of dialog this should become, either deleteRow or deleteColumn
* @param remove a list of all the rows or columns that should be deleted.
*/
- KWDeleteDia( KWView *parent, KWTableFrameSet *table, DeleteType type, QValueList<uint> remove);
+ KWDeleteDia( KWView *tqparent, KWTableFrameSet *table, DeleteType type, TQValueList<uint> remove);
protected:
void setupTab1();
@@ -54,7 +55,7 @@ protected:
KWTableFrameSet *m_table;
DeleteType m_type;
- QValueList<uint> m_toRemove;
+ TQValueList<uint> m_toRemove;
protected slots:
virtual void slotOk();
@@ -33,19 +33,20 @@ class KWView;
/**
* Constructor for the ok-to-delete dialog.
- * @param parent the parent widget
+ * @param tqparent the tqparent widget
* @param name the internal name for the widget
* @param table the table the rows or columns are to be deleted from